/*
 * This file is part of Geomajas, a component framework for building
 * rich Internet applications (RIA) with sophisticated capabilities for the
 * display, analysis and management of geographic information.
 * It is a building block that allows developers to add maps
 * and other geographic data capabilities to their web applications.
 *
 * Copyright 2008-2010 Geosparc, http://www.geosparc.com, Belgium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.geomajas.plugin.geocoder.service;

import com.vividsolutions.jts.geom.Envelope;
import org.geomajas.global.Api;
import org.geomajas.plugin.geocoder.api.CombineResultService;
import org.geomajas.plugin.geocoder.api.GetLocationResult;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * Combine locations by taking the union of the areas.
 *
 * @author Joachim Van der Auwera
 * @since 1.0.0
 */
@Api
@Component
public class CombineUnionService implements CombineResultService {
	public Envelope combine(List<GetLocationResult> results) {
		Envelope result = null;
		for (GetLocationResult add : results) {
			Envelope envelope = add.getEnvelope();
			if (null == result) {
				result = envelope;
			} else {
				result.expandToInclude(envelope);
			}
		}
		return result;
	}
}
